@@ -1,19 +1,20 @@
+#[export]
 bic.corfsreg <- function (y, x, tol = 2) {
     dm <- dim(x)
     n <- dm[1]
     p <- dm[2]
     con <- n * log(2 * pi) + n
     logn <- log(n)
-    x <- Rfast::standardise(x, center = TRUE, scale = FALSE)
-    y <- y - mean(y)
+    x <- Rfast::standardise(x, center = TRUE, scale = TRUE)
+    y <- ( y - mean(y) ) / Rfast::Var(y)
     model <- NULL
     tool <- sela <- numeric( min(n, p) )
     tool[1] <- n * log( Var(y) * (n - 1) /n) + 2 * logn 
     sela[1] <- 0
 	options(warn = -1)
-    yx <- cor(y, x)
+    yx <- Rfast::eachcol.apply(x, y)
     sel <- which.max(abs(yx))
-    r <- yx[sel]
+    r <- yx[sel] / (n - 1)
     z <- x[, sel, drop = FALSE]
     x[, sel] <- 0
     model <- .lm.fit(as.matrix(z), y)
@@ -23,10 +24,13 @@ bic.corfsreg <- function (y, x, tol = 2) {
     while ( k < n - 19 & tool[k - 1] - tool[k] > tol ) {
       m <- n - 3 - k
       k <- k + 1
-      e1 <- .lm.fit(z, y)$residuals
-      e2 <- .lm.fit(z, x)$residuals
+      #e1 <- .lm.fit(z, y)$residuals
+      #e2 <- .lm.fit(z, x)$residuals
+      res <- .lm.fit(z, cbind(y, x))$residuals
+      e1 <- res[, 1]
+      e2 <- res[, -1]
       options(warn = -1)
-      yx.z <- cor(e2, e1)
+      yx.z <- cor(e1, e2)
       sel <- which.max( abs(yx.z) )
       z <- cbind(z, x[, sel])
       x[, sel] <- 0
