@@ -1,9 +1,10 @@
+#[export]
 poisson.anova <- function(y, ina, logged = FALSE) {
   ni <- tabulate(ina)
   ni <- ni[ni > 0]
   k <- length(ni)
   n <- sum(ni)
-  si <- Rfast::group.sum(y, ina)
+  si <- Rfast::group(y, ina)
   mi <- si/ni
   d1 <- sum( si * log(mi) )
   d0 <- sum(si) * log(sum( si)/n )  
