@@ -1,5 +1,6 @@
+#[export]
 sftests <- function(x, logged = FALSE) {
-  x <- Rfast::sort_mat(x)
+  x <- Rfast::colSort(x)
   n <- dim(x)[1]
   y <- qnorm( ( 1:n - 0.375 ) / (n + 0.25) ) 
   w <- as.vector( cor(y, x)^2 )
