@@ -41,7 +41,7 @@ BEGIN_RCPP
     traits::input_parameter< NumericMatrix >::type X(XSEXP);
     traits::input_parameter< const bool >::type sqr(sqrSEXP);
     traits::input_parameter< const string >::type type(typeSEXP);
-    __result = wrap(dista(Xnew,X,sqr,type));
+    __result = dista(Xnew,X,sqr,type);
     return __result;
 
 END_RCPP
@@ -72,7 +72,7 @@ BEGIN_RCPP
     traits::input_parameter< NumericMatrix >::type X(XSEXP);
     traits::input_parameter< const int >::type k(kSEXP);
     traits::input_parameter< const string >::type type(typeSEXP);
-    __result = wrap(dista_index(Xnew,X,k,type));
+    __result = dista_index(Xnew,X,k,type);
     return __result;
 
 END_RCPP
@@ -96,7 +96,7 @@ NumericMatrix dista_values(NumericMatrix Xnew, NumericMatrix X,const int k,const
         disa.col(i)=get_k_values(sum(square(x.each_col() - xnew.col(i)),0),k);
     }else{
       for(int i=0;i<nu;++i){
-        disa.col(i)=foreach<std::sqrt,rowvec>(get_k_values(sum(square(x.each_col() - xnew.col(i)),0),k));
+        disa.col(i)=foreach<std::sqrt,colvec>(get_k_values(sum(square(x.each_col() - xnew.col(i)),0),k));
       }
     }
   }else if(type == "manhattan"){
@@ -116,7 +116,7 @@ BEGIN_RCPP
     traits::input_parameter< const int >::type k(kSEXP);
     traits::input_parameter< const bool >::type sqr(sqrSEXP);
     traits::input_parameter< const string >::type type(typeSEXP);
-    __result = wrap(dista_values(Xnew,X,k,sqr,type));
+    __result = dista_values(Xnew,X,k,sqr,type);
     return __result;
 
 END_RCPP
